%define fedora          0
%define redhat          1
%if %{fedora}
%define gcj_support     1
%else
%define gcj_support     0
%endif

# All arches line up except i386 -> x86
%ifarch %{ix86}
%define eclipse_arch    x86
%else
%define eclipse_arch   %{_arch}
%endif

%define eclipse_base	%{_datadir}/eclipse
%define eclipse_lib     %{_libdir}/eclipse

Name:           eclipse-oprofile
Version:        1.2.1
Release:        1
Summary:        OProfile plugins for Eclipse

Group:          Development/Tools
License:        EPL/GPL
URL:            http://dev.eclipse.org/viewcvs/index.cgi/~checkout~/org.eclipse.cdt-contrib/org.eclipse.cdt.oprofile-home/index.html?cvsroot=Tools_Project

# Making a tarball:
# $ cvs -d:pserver:anonymous@dev.eclipse.org:/cvsroot/tools co -r v1_2_1 org.eclipse.cdt-contrib/org.eclipse.cdt.oprofile
# $ cd org.eclipse.cdt-contrib
# $ find org.eclipse.cdt.oprofile -name CVS | xargs rm -rf
# $ mv org.eclipse.cdt.oprofile eclipse-oprofile-1.2.1
# $ tar zcf eclipse-oprofile-1.2.1.tar.gz eclipse-oprofile-1.2.1
Source0:        %{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot

BuildRequires:          eclipse-pde
BuildRequires:          eclipse-cdt
BuildRequires:          oprofile-devel >= 0.8
BuildRequires:	        binutils

%if %{gcj_support}
BuildRequires:		gcc-java >= 4.0.2
BuildRequires:		java-gcj-compat-devel >= 1.0.33
Requires(post):		java-gcj-compat >= 1.0.33
Requires(postun):	java-gcj-compat >= 1.0.33
%else
BuildRequires:		java-devel >= 1.4.2
%endif

ExclusiveArch:		%{ix86} x86_64 ia64

Requires:               eclipse-platform
Requires:               eclipse-cdt
Requires:               oprofile
Requires:               binutils
Requires:               usermode

%description
The eclipse-oprofile package contains Eclipse plugins for the
OProfile package.

%prep
%setup -q 

%build
# Eclipse may try to write to the home directory.
mkdir home
homedir=$(cd home > /dev/null && pwd)

# Build the OProfile feature
java -cp %{eclipse_base}/startup.jar                   \
     -Duser.home=$homedir                              \
     org.eclipse.core.launcher.Main                    \
     -application org.eclipse.ant.core.antRunner       \
     -Dtype=feature                                    \
     -Did=org.eclipse.cdt.oprofile                     \
     -Dbuilder=%{eclipse_base}/plugins/org.eclipse.pde.build/templates/package-build \
     -DsourceDirectory=$(pwd)                          \
     -DbaseLocation=%{eclipse_base}                    \
     -f %{eclipse_base}/plugins/org.eclipse.pde.build/scripts/build.xml

# needed because Eclipse and package-build don't support building native code
# Side effect: opxml will NOT be included in the jar file! Must install
# it independently.
pushd build/plugins/org.eclipse.cdt.oprofile.core.linux/src
java -cp %{eclipse_base}/startup.jar                   \
     -Duser.home=$homedir                              \
     org.eclipse.core.launcher.Main                    \
     -application org.eclipse.ant.core.antRunner       \
     -DCXX=g++                                         \
     -Dbaseos=linux                                    \
     -Dbasearch=%{eclipse_arch}
popd

%install
rm -rf ${RPM_BUILD_ROOT}
install -d -m 755 ${RPM_BUILD_ROOT}/%{eclipse_base}
unzip -q -d ${RPM_BUILD_ROOT}/%{eclipse_base}/.. build/rpmBuild/org.eclipse.cdt.oprofile.zip
# hack to get around bug in package build
mkdir -p ${RPM_BUILD_ROOT}/%{eclipse_base}/features/org.eclipse.cdt.oprofile_%{version}
cp -r build/features/org.eclipse.cdt.oprofile/*  ${RPM_BUILD_ROOT}/%{eclipse_base}/features/org.eclipse.cdt.oprofile_%{version}
# end hack to get around bug in package build
%if %{gcj_support}
  aot-compile-rpm
%endif

# Install the security files to grant root permission to (our own) opcontrol users
install -D -m 644 ${RPM_BUILD_ROOT}/%{eclipse_base}/plugins/org.eclipse.cdt.oprofile.core.linux_%{version}/opcontrol-wrapper.security ${RPM_BUILD_ROOT}/etc/security/console.apps/opcontrol
install -D -m 644 ${RPM_BUILD_ROOT}/%{eclipse_base}/plugins/org.eclipse.cdt.oprofile.core.linux_%{version}/opcontrol-wrapper.pamd ${RPM_BUILD_ROOT}/etc/pam.d/opcontrol

# Install opxml (hack to get around native build problems in package build)
# and fix permissions (since Eclipse's jar tool doesn't preserve them)
install -D build/plugins/org.eclipse.cdt.oprofile.core.linux/os/linux/%{eclipse_arch}/opxml ${RPM_BUILD_ROOT}/%{eclipse_lib}/plugins/org.eclipse.cdt.oprofile.core.linux_%{version}/os/linux/%{eclipse_arch}/opxml

# Update permissions. In the public, update-perms is used, but that doesn't work so
# well with RPM builds. Just do it manually here.
pushd ${RPM_BUILD_ROOT}/%{eclipse_base}/plugins/org.eclipse.cdt.oprofile.core.linux_%{version}
chmod +x update-perms
chmod +x install
chmod +x uninstall
chmod +x opcontrol
popd

# Link actual opxml install to plugin directory
install -d ${RPM_BUILD_ROOT}/%{eclipse_base}/plugins/org.eclipse.cdt.oprofile.core.linux_%{version}/os/linux/%{eclipse_arch}
ln -sf %{eclipse_lib}/plugins/org.eclipse.cdt.oprofile.core.linux_%{version}/os/linux/%{eclipse_arch}/opxml ${RPM_BUILD_ROOT}/%{eclipse_base}/plugins/org.eclipse.cdt.oprofile.core.linux_%{version}/os/linux/%{eclipse_arch}/opxml 

%clean
rm -rf ${RPM_BUILD_ROOT}

%if %{gcj_support}
%post
%{_bindir}/rebuild-gcj-db
%postun
%{_bindir}/rebuild-gcj-db
%endif

%files
%defattr(-,root,root)
%{eclipse_base}/features/org.eclipse.cdt.oprofile_*
%{eclipse_base}/plugins/org.eclipse.cdt.oprofile.core_*
%{eclipse_base}/plugins/org.eclipse.cdt.oprofile.core.linux_*
%{eclipse_base}/plugins/org.eclipse.cdt.oprofile.launch_*
%{eclipse_base}/plugins/org.eclipse.cdt.oprofile.ui_*
%{eclipse_base}/plugins/org.eclipse.cdt.oprofile.doc_*
%{_libdir}/eclipse/plugins/org.eclipse.cdt.oprofile.core.linux_%{version}/os/linux/%{eclipse_arch}/opxml
%if %{gcj_support}
%{_libdir}/gcj/%{name}/* 
%endif

%config(noreplace) /etc/security/console.apps/opcontrol
%config(noreplace) /etc/pam.d/opcontrol

%changelog
* Wed Aug  9 2006 Keith Seitz <keiths@redhat.com> 1.2.1-1
- Build against Eclipse 3.2.0 and CDT 3.1.0.
- Manually change permissions instead of using update-perms script.
- Misc changes suggested by Andrew Overholt (overholt@redhat.com).

* Mon Apr  3 2006 Keith Seitz <keiths@redhat.com> 1.2.0-6
- Build against Eclipse 3.1.2.
- Fix some plugin bugs.
- Update spec file to use new package building.

* Tue Jun 28 2005 Aaron Luchko <aluchko@redhat.com> 1.2.0-3
- Added x86_64

* Mon May 2 2005 Ben Konrath <bkonrath@redhat.com> 1.2.0-2
- Build against Eclipse 3.0.2.

* Mon Apr  4 2005 Keith Seitz <keiths@redhat.com> 1.2.0-1
- Update for Oprofile-0.8 & eclipse.org sources

* Mon Jul 26 2004 Keith Seitz <keiths@redhat.com> 1.1.0-5
- Disable on ppc

 Fri Jul 23 2004 Jeremy Handcock <handcock@redhat.com> 1.1.0-4
- Define eclipse_arch and java_arch on ppc

* Fri Jul 23 2004 Jeremy Handcock <handcock@redhat.com> 1.1.0-3
- Require eclipse-ui, not eclipse-platform
- Set user.home property for build

* Thu Jul 22 2004 Jeremy Handcock <handcock@redhat.com> 1.1.0-2
- Correct Requires eclipse -> eclipse-platform
- Don't BuildRequires ant
- Correct BuildRequires eclipse -> eclipse-platform
- Don't build on ppc64

* Tue Jul 20 2004 Keith Seitz <keiths@redhat.com> 1.1.0-1
- Use copy-platform. See remarks in that file for details
- Install opxml executable in _libdir; make a symlink to it in eclipse_base

* Sun Jul 18 2004 Keith Seitz <keiths@redhat.com>
- Append build config to build.properties.

* Wed Jul 16 2004 Keith Seitz <keiths@redhat.com>
- Reworked for 3.0 and its new build system

* Mon Jan 19 2004 Tom Tromey <tromey@redhat.com> 1.0.0-1
- Initial version
